@@ -12,28 +12,57 @@ identical3 <- function(x,y,z)	  identical(x,y) && identical (y,z)
 identical4 <- function(a,b,c,d)   identical(a,b) && identical3(b,c,d)
 identical5 <- function(a,b,c,d,e) identical(a,b) && identical4(b,c,d,e)
 
-## Make sure errors are signaled
-assertError <- function(expr) {
+if( exists("assertCondition", asNamespace("tools")) ) { ## R > 3.0.1
+
+assertError <- function(expr, verbose=getOption("verbose"))
+    tools::assertCondition(expr, "error", verbose=verbose)
+assertWarning <- function(expr, verbose=getOption("verbose"))
+    tools::assertCondition(expr, "warning", verbose=verbose)
+assertWarningAtLeast <- function(expr, verbose=getOption("verbose"))
+    tools::assertCondition(expr, "error", "warning", verbose=verbose)
+
+} else { ## in R <= 3.0.1, use our old versions
+
+##' @title Ensure evaluating 'expr' signals an error
+##' @param expr
+##' @return the caught error, invisibly
+##' @author Martin Maechler
+assertError <- function(expr, verbose=getOption("verbose")) {
     d.expr <- deparse(substitute(expr))
     t.res <- tryCatch(expr, error = function(e) e)
     if(!inherits(t.res, "error"))
 	stop(d.expr, "\n\t did not give an error", call. = FALSE)
+    cat("Asserted Error:", conditionMessage(t.res),"\n")
     invisible(t.res)
 }
-assertWarningAtLeast <- function(expr) {
+
+##' @title Ensure evaluating 'expr' signals a warning or an error
+##' @param expr
+##' @return the caught error/warning, invisibly
+##' @author Martin Maechler
+assertWarningAtLeast <- function(expr, verbose=getOption("verbose")) {
     d.expr <- deparse(substitute(expr))
     t.res <- tryCatch(expr, error = function(e)e, warning = function(w)w)
-    if(!inherits(t.res, "error") && !inherits(t.res, "warning"))
+    if(!(isE <- inherits(t.res, "error")) && !inherits(t.res, "warning"))
 	stop(d.expr, "\n\t did not give an error or warning", call. = FALSE)
+    if(verbose) cat("Asserted", if(isE) "Error:" else "Warning:",
+		    conditionMessage(t.res),"\n")
     invisible(t.res)
 }
-assertWarning <- function(expr) {
+
+##' @title Ensure evaluating 'expr' signals a warning
+##' @param expr
+##' @return the caught warning, invisibly
+##' @author Martin Maechler
+assertWarning <- function(expr, verbose=getOption("verbose")) {
     d.expr <- deparse(substitute(expr))
     t.res <- tryCatch(expr, warning = function(w)w)
     if(!inherits(t.res, "warning"))
 	stop(d.expr, "\n\t did not give a warning", call. = FALSE)
+    if(verbose) cat("Asserted Warning:", conditionMessage(t.res),"\n")
     invisible(t.res)
 }
+}# [else: no assertCondition ]
 
 ##' [ from R's  demo(error.catching) ]
 ##' We want to catch *and* save both errors and warnings, and in the case of
@@ -151,6 +180,19 @@ S4_2list <- function(obj) {
    structure(lapply(sn, slot, object = obj), .Names = sn)
 }
 
+assert.EQ <- function(target, current, tol = if(show) 0 else 1e-15,
+                      giveRE = FALSE, show = FALSE, ...) {
+    ## Purpose: check equality *and* show non-equality
+    ## ----------------------------------------------------------------------
+    ## show: if TRUE, return (and hence typically print) all.equal(...)
+    T <- isTRUE(ae <- all.equal(target, current, tol = tol, ...))
+    if(show) return(ae) else if(giveRE && T) { ## don't show if stop() later:
+	ae0 <- if(tol == 0) ae else all.equal(target, current, tol = 0, ...)
+	if(!isTRUE(ae0)) cat(ae0,"\n")
+    }
+    if(!T) stop("all.equal() |-> ", paste(ae, collapse=sprintf("%-19s","\n")))
+}
+
 
 ### ------- Part II  -- related to matrices, but *not* "Matrix" -----------
 
@@ -169,7 +211,7 @@ as.mat <- function(m) {
     m
 }
 
-assert.EQ.mat <- function(M, m, tol = if(show) 0 else 1e-15, show=FALSE) {
+assert.EQ.mat <- function(M, m, tol = if(show) 0 else 1e-15, show=FALSE, giveRE = FALSE, ...) {
     ## Purpose: check equality of  'Matrix' M with  'matrix' m
     ## ----------------------------------------------------------------------
     ## Arguments: M: is(., "Matrix") typically {but just needs working as(., "matrix")}
@@ -180,13 +222,11 @@ assert.EQ.mat <- function(M, m, tol = if(show) 0 else 1e-15, show=FALSE) {
     if(is.logical(MM) && is.numeric(m))
 	storage.mode(MM) <- "integer"
     attr(MM, "dimnames") <- attr(m, "dimnames") <- NULL
-    if(show) all.equal(MM, m, tol = tol)
-    else if(!isTRUE(r <- all.equal(MM, m, tol = tol)))
-	stop("all.equal() |->  ", r)
+    assert.EQ(MM, m, tol=tol, show=show, giveRE=giveRE)
 }
 ## a short cut
-assert.EQ.Mat <- function(M, M2, tol = if(show) 0 else 1e-15, show=FALSE)
-    assert.EQ.mat(M, as.mat(M2), tol=tol, show=show)
+assert.EQ.Mat <- function(M, M2, tol = if(show) 0 else 1e-15, show=FALSE, giveRE = FALSE, ...)
+    assert.EQ.mat(M, as.mat(M2), tol=tol, show=show, giveRE=giveRE)
 
 
 chk.matrix <- function(M) {
