@@ -3,12 +3,11 @@
 /* ========================================================================== */
 
 /* -----------------------------------------------------------------------------
- * CHOLMOD/Supernodal Module.  Version 1.2.
- * Copyright (C) 2005-2006, Timothy A. Davis
+ * CHOLMOD/Supernodal Module.  Copyright (C) 2005-2006, Timothy A. Davis
  * The CHOLMOD/Supernodal Module is licensed under Version 2.0 of the GNU
  * General Public License.  See gpl.txt for a text of the license.
  * CHOLMOD is also available under other licenses; contact authors for details.
- * http://www.cise.ufl.edu/research/sparse
+ * http://www.suitesparse.com
  * -------------------------------------------------------------------------- */
 
 /* Computes the Cholesky factorization of A+beta*I or A*F+beta*I.  Only the
@@ -63,9 +62,18 @@
 #include "cholmod_supernodal.h"
 
 /* ========================================================================== */
-/* === TEMPLATE ============================================================= */
+/* === TEMPLATE codes for GPU and regular numeric factorization ============= */
 /* ========================================================================== */
 
+#ifdef GPU_BLAS
+#define REAL
+#include "t_cholmod_gpu.c"
+#define COMPLEX
+#include "t_cholmod_gpu.c"
+#define ZOMPLEX
+#include "t_cholmod_gpu.c"
+#endif
+
 #define REAL
 #include "t_cholmod_super_numeric.c"
 #define COMPLEX
@@ -288,7 +296,8 @@ int CHOLMOD(super_numeric)
 
     /* Flag array was used as workspace, clear it */
     Common->mark = EMPTY ;
-    CHOLMOD(clear_flag) (Common) ;
+    /* CHOLMOD(clear_flag) (Common) ; */
+    CHOLMOD_CLEAR_FLAG (Common) ;
     ASSERT (CHOLMOD(dump_work) (TRUE, TRUE, 0, Common)) ;
     CHOLMOD(free_dense) (&C, Common) ;
     return (ok) ;
